From fd0d083b11293023c945720a0f3b2e1eb27d8a34 Mon Sep 17 00:00:00 2001
From: Enrico Guiraud <enrico.guiraud@cern.ch>
Date: Wed, 14 Nov 2018 23:57:57 +0100
Subject: [PATCH] [DF][NFC] Use consistent naming for function parameter

---
 tree/dataframe/inc/ROOT/RDF/Utils.hxx | 2 +-
 tree/dataframe/src/RDFUtils.cxx       | 6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/tree/dataframe/inc/ROOT/RDF/Utils.hxx b/tree/dataframe/inc/ROOT/RDF/Utils.hxx
index 4a528bdd38a..a555ca0b243 100644
--- a/tree/dataframe/inc/ROOT/RDF/Utils.hxx
+++ b/tree/dataframe/inc/ROOT/RDF/Utils.hxx
@@ -64,7 +64,7 @@ const std::type_info &TypeName2TypeID(const std::string &name);
 std::string TypeID2TypeName(const std::type_info &id);
 
 std::string ColumnName2ColumnTypeName(const std::string &colName, unsigned int namespaceID, TTree *, RDataSource *,
-                                      bool isCustomColumn, bool extraConversions = true, unsigned int customColID = 0);
+                                      bool isCustomColumn, bool vector2rvec = true, unsigned int customColID = 0);
 
 char TypeName2ROOTTypeName(const std::string &b);
 
diff --git a/tree/dataframe/src/RDFUtils.cxx b/tree/dataframe/src/RDFUtils.cxx
index ed815bcd69b..91c217225d6 100644
--- a/tree/dataframe/src/RDFUtils.cxx
+++ b/tree/dataframe/src/RDFUtils.cxx
@@ -180,11 +180,11 @@ std::string GetBranchOrLeafTypeName(TTree &t, const std::string &colName)
 /// Return a string containing the type of the given branch. Works both with real TTree branches and with temporary
 /// column created by Define. Throws if type name deduction fails.
 /// Note that for fixed- or variable-sized c-style arrays the returned type name will be RVec<T>.
 /// vector2tvec specifies whether typename 'std::vector<T>' should be converted to 'RVec<T>' or returned as is
 /// customColID is only used if isCustomColumn is true, and must correspond to the custom column's unique identifier
 /// returned by its `GetID()` method.
 std::string ColumnName2ColumnTypeName(const std::string &colName, unsigned int namespaceID, TTree *tree,
-                                      RDataSource *ds, bool isCustomColumn, bool vector2tvec, unsigned int customColID)
+                                      RDataSource *ds, bool isCustomColumn, bool vector2rvec, unsigned int customColID)
 {
    std::string colType;
 
@@ -193,7 +193,7 @@ std::string ColumnName2ColumnTypeName(const std::string &colName, unsigned int n
 
    if (colType.empty() && tree) {
       colType = GetBranchOrLeafTypeName(*tree, colName);
-      if (vector2tvec && TClassEdit::IsSTLCont(colType) == ROOT::ESTLType::kSTLvector) {
+      if (vector2rvec && TClassEdit::IsSTLCont(colType) == ROOT::ESTLType::kSTLvector) {
          std::vector<std::string> split;
          int dummy;
          TClassEdit::GetSplit(colType.c_str(), split, dummy);
@@ -180,11 +180,11 @@ std::string GetBranchOrLeafTypeName(TTree &t, const std::string &colName)
 /// column created by Define. Throws if type name deduction fails.
 /// Note that for fixed- or variable-sized c-style arrays the returned type name will be RVec<T>.
-/// vector2tvec specifies whether typename 'std::vector<T>' should be converted to 'RVec<T>' or returned as is
+/// vector2rvec specifies whether typename 'std::vector<T>' should be converted to 'RVec<T>' or returned as is
 /// customColID is only used if isCustomColumn is true, and must correspond to the custom column's unique identifier
 /// returned by its `GetID()` method.
-- 
GitLab